@@ -23,8 +23,8 @@ function(y1vec, y2vec, x1Matr, x2Matr, eststage1, eststage2, eststage2sigma, wei
       s2=s2 + t.c*weights[i]*drop(dLambdadSM5(x1Matr[i,],eststage1$coeff))*(x1Matr[i,])
     }
     else {
-      s1=s1 + ( x2Matr[i,1:dim(x2Matr)[2]-1] )%*%t(x1Matr[i,])*eststage2[dim(x2Matr)[2]]*weights[i]*drop(dLambdadSM5(x1Matr[i,],eststage1$coeff))/eststage2sigma
-      s2=s2 + (x2Matr[i,dim(x2Matr)[2]]*eststage2[dim(x2Matr)[2]])*weights[i]*dLambdadSM5(x1Matr[i,],eststage1$coeff)/eststage2sigma*x1Matr[i,]
+      s1=s1 + (x2Matr[i,1:dim(x2Matr)[2]-1])%*%t(x1Matr[i,])*eststage2[dim(x2Matr)[2]]*weights[i]*drop(dLambdadSM5(x1Matr[i,],eststage1$coeff))/eststage2sigma
+      s2=s2 + (x2Matr[i,dim(x2Matr)[2]]*eststage2[dim(x2Matr)[2]])*weights[i]*c(dLambdadSM5(x1Matr[i,],eststage1$coeff))/eststage2sigma*x1Matr[i,]
     }
   }
   xdx=rbind(s1,s2)
